<?php
/**
 * Revolve functions and definitions.
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Revolve
 */

if ( ! function_exists( 'revolve_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function revolve_setup() {
	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on Revolve, use a find and replace
	 * to change 'revolve' to the name of your theme in all the template files.
	 */
	load_theme_textdomain( 'revolve', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
	 */
	add_theme_support( 'post-thumbnails' );

	/** Add Woocommerce Support **/
	add_theme_support( 'woocommerce' );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary' => esc_html__( 'Primary', 'revolve' ),
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form',
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );

	/*
	 * Enable support for Post Formats.
	 * See https://developer.wordpress.org/themes/functionality/post-formats/
	 */
	/*add_theme_support( 'post-formats', array(
		'aside',
		'image',
		'video',
		'quote',
		'link',
	) ); */

	// Set up the WordPress core custom background feature.
	add_theme_support( 'custom-background', apply_filters( 'revolve_custom_background_args', array(
		'default-color' => 'ffffff',
		'default-image' => '',
	) ) );
}
endif; // revolve_setup
add_action( 'after_setup_theme', 'revolve_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function revolve_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'revolve_content_width', 640 );
}
add_action( 'after_setup_theme', 'revolve_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function revolve_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'revolve' ),
		'id'            => 'sidebar-1',
		'description'   => '',
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
}
add_action( 'widgets_init', 'revolve_widgets_init' );

/** Adding Image Sizes **/
add_image_size( 'revolve-port-grid-thumb', 480, 480, true );
add_image_size( 'revolve-blog-grid-thumb', 500, 500, true );

/**
 * Enqueue scripts and styles.
 */
function revolve_scripts() {
	$font_args = array(
        'family' => 'Open+Sans:400,300,400italic,600,700|Open+Sans+Condensed:300,700',
    );

    wp_enqueue_style('revolve-google-fonts', add_query_arg($font_args, "//fonts.googleapis.com/css"));

	wp_enqueue_style( 'revolve-style', get_stylesheet_uri() );
	wp_enqueue_style( 'revolve-responsive-css', get_template_directory_uri().'/css/responsive.css');
    wp_enqueue_style( 'revolve-faw', get_template_directory_uri().'/assets/faw/css/font-awesome.css');
    wp_enqueue_style( 'revolve-tiny-lightbox-css', get_template_directory_uri().'/assets/tiny-lightbox/viewbox.css');
    wp_enqueue_style( 'revolve-mcustomscrollbar', get_template_directory_uri().'/assets/scbar/jquery.mCustomScrollbar.css');
    wp_enqueue_style( 'revolve-jquery-ui-css', '//code.jquery.com/ui/1.11.4/themes/smoothness/jquery-ui.css');
    
    if(is_page_template('tpl-home.php')) {
        wp_enqueue_style( 'revolve-onepage-scroll-css', get_template_directory_uri() . '/assets/onepage-scroll/onepage-scroll.css' );
        wp_enqueue_script( 'revolve-onepage-scroll-js', get_template_directory_uri() . '/assets/onepage-scroll/jquery.onepage-scroll.js', array('jquery') );
        wp_enqueue_script( 'revolve-home-custom-js', get_template_directory_uri() . '/js/home-custom.js', array('jquery', 'jquery-ui-core', 'revolve-onepagenav-js') );
    }

    wp_enqueue_script( 'revolve-smooth-scroll-js', get_template_directory_uri() . '/js/jquery.smooth-scroll.js', array('jquery') );
    
    wp_enqueue_script( 'revolve-scrollto-js', get_template_directory_uri() . '/js/jquery.scrollTo.js', array('jquery', 'revolve-smooth-scroll-js') );
    
    wp_enqueue_script( 'revolve-onepagenav-js', get_template_directory_uri() . '/js/jquery.nav.js', array('jquery', 'revolve-scrollto-js') );
    
    wp_enqueue_script( 'revolve-tiny-lightbox-js', get_template_directory_uri() . '/assets/tiny-lightbox/jquery.viewbox.js', array('jquery'));

    wp_enqueue_script( 'revolve-mcustomscrollbar-js', get_template_directory_uri() . '/assets/scbar/jquery.mCustomScrollbar.js', array('jquery'));
    
    wp_enqueue_script( 'revolve-custom-js', get_template_directory_uri() . '/js/custom.js', array('jquery', 'jquery-ui-core', 'revolve-onepagenav-js', 'revolve-tiny-lightbox-js', 'revolve-mcustomscrollbar-js') );


	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'revolve_scripts' );

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Load extra Customizer Controls.
 */
require get_template_directory() . '/inc/cmizer/revolve-extra-controls.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';

/**
 * Load Extra Customizer Controls
 */

require get_template_directory() . '/inc/revolve-extra-controls.php';

/**
 * Load Nav Menu Custom Added Options
 */
require get_template_directory() . '/inc/revolve-custom-menu.php';

/**
 * Load Revolve Custom Function Page
 */
require get_template_directory() . '/inc/revolve-functions.php';

/**
 * Load Revolve Additional Widgets
 */
require get_template_directory() . '/inc/revolve-widgets.php';

/**
 * Load Revolve Woocommerce
 */
require get_template_directory() . '/inc/revolve-woo.php';

function revolve_add_editor_styles() {
    add_editor_style( 'custom-editor-style.css' );
}
add_action( 'admin_init', 'revolve_add_editor_styles' );

/** Add Portfolio Class to Portfoliio Single Page **/
function revolve_portfolio_class( $classes ) {
	global $post;
	$post_cats = array();
	$port_class = '';
	if(is_single()) :
		$categories = get_the_category($post->ID);
		if(!empty($categories)){
			foreach($categories as $cat) {
				$post_cats[] = $cat->term_id;
			}
		}

		$port_category = get_theme_mod('port_category', 0);
		if($port_category != '' || $port_category != 0 || !empty($post_cats)) {
			if(in_array($port_category, $post_cats)) {
				$port_class = 'single-portfolio-post';
			}
		}
		foreach ( get_the_category( $post->ID ) as $category ) {
			$classes[] = $port_class;
		}
	endif;
	return $classes;
}
add_filter( 'body_class', 'revolve_portfolio_class' );

/** Allowing SVG images **/
function cc_mime_types($mimes) {
  $mimes['svg'] = 'image/svg+xml';
  return $mimes;
}
add_filter('upload_mimes', 'cc_mime_types');

/*function revolve_woo_after_shop_loop () {
	?>
		</div><!-- padding -->
	<?php
}
add_action('woocommerce_before_shop_loop', 'revolve_woo_after_shop_loop');

function revolve_woo_page_title () {
	?>
		<div class="rev-woo-container"><!-- padding -->
	<?php
}
add_action('woocommerce_page_title', 'revolve_woo_page_title');
*/