<?php
/**
 * The header for our theme.
 *
 * This is the template that displays all of the <head> section and everything up until <div id="content">
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package Revolve
 */

?>
<!DOCTYPE html>
<html <?php language_attributes(); ?>>
<head>
<meta charset="<?php bloginfo( 'charset' ); ?>">
<meta name="viewport" content="width=device-width, initial-scale=1">
<link rel="profile" href="http://gmpg.org/xfn/11">
<link rel="pingback" href="<?php bloginfo( 'pingback_url' ); ?>">

<?php wp_head(); ?>
</head>

<body <?php body_class(); ?>>
        <div id="menu-toggle"><i class="fa fa-bars"></i></div>
        <div id="revolve-side-nav" class="nano">
        	<header id="revolve-masthead" class="revolve-site-header" role="banner">
                <?php
                    $header_logo = esc_url(get_theme_mod('header_logo', ''));
                    $header_display = esc_attr(get_theme_mod('header_display', 'text_only'));
                    $slg_class = ($header_display == 'both') ? 'both' : 'one';
                ?>
        		<div id="revolve-site-branding" class="<?php echo $slg_class; ?>">
                    <?php if($header_display == 'text_only') : ?>
                        <div class="revolve-site-tagline">
            				<p class="revolve-site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
                			<?php            
                			$description = get_bloginfo( 'description', 'display' );
                			if ( $description || is_customize_preview() ) : ?>
                				<a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><p class="revolve-site-description"><?php echo $description; ?></p></a>
                			<?php
                			endif; ?>
                        </div>
                    <?php elseif($header_display == 'logo_only') : ?>
                        <?php if($header_logo != '') : ?>
                            <div class="revolve-site-logo">
                                <a href="<?php echo esc_url( home_url( '/' ) ); ?>">
                                    <img src="<?php echo $header_logo; ?>" />
                                </a>
                            </div>
                        <?php endif; ?>
                    <?php else : ?>
                        <?php if($header_logo != '') : ?>
                            <div class="revolve-site-logo">
                                <a href="<?php echo esc_url( home_url( '/' ) ); ?>">
                                    <img src="<?php echo $header_logo; ?>" />
                                </a>
                            </div>
                        <?php endif; ?>
                        <div class="revolve-site-tagline">
            				<p class="revolve-site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
                			<?php
                
                			$description = get_bloginfo( 'description', 'display' );
                			if ( $description || is_customize_preview() ) : ?>
                				<a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><p class="revolve-site-description"><?php echo $description; ?></p></a>
                			<?php
                			endif; ?>
                        </div>
                    <?php endif; ?>
        		</div><!-- .site-branding -->
            </header><!-- #masthead -->

        	<nav id="site-navigation" class="main-navigation" role="navigation">
                <?php if(has_nav_menu('primary')) : ?>
                    <?php wp_nav_menu( array( 'theme_location' => 'primary', 'container' => false, 'walker' => new Revolve_Walker_Nav_Menu() ) ); ?>
                <?php else : ?>
                    <ul class="menu">

                    <li><a href="<?php echo home_url(); ?>/">Home</a></li>
                    <?php wp_list_pages('title_li=' ); ?>

                    </ul><!-- end .menu -->
                <?php endif; ?>
        	</nav><!-- #site-navigation -->

            <?php
                /** Social Icons **/
                $social_fb = get_theme_mod('social_fb', '');
                $social_tw = get_theme_mod('social_tw', '');
                $social_gplus = get_theme_mod('social_gplus', '');
                $social_lnk = get_theme_mod('social_lnk', '');
                $social_ytube = get_theme_mod('social_ytube', '');
            ?>
            <?php if($social_fb != '' || $social_tw != '' || $social_gplus != '' || $social_lnk != '' || $social_ytube != '') : ?>
                <div class="header-social-icons-container">
                    <div class="rvl-header-social-icons">
                        <ul class="social-icons">
                            <?php if($social_fb != '') : ?>
                            <li class="c-circle-nav__item">
                                <a href="#" class="c-circle-nav__link">
                                    <i class="fa fa-facebook"></i>
                                </a>
                            </li>
                            <?php endif; ?>
                            <?php if($social_tw != '') : ?>
                            <li class="c-circle-nav__item">
                                <a href="#" class="c-circle-nav__link">
                                    <i class="fa fa-twitter"></i>
                                </a>
                            </li>
                            <?php endif; ?>
                            <?php if($social_gplus != '') : ?>
                            <li class="c-circle-nav__item">
                                <a href="#" class="c-circle-nav__link">
                                    <i class="fa fa-google"></i>
                                </a>
                            </li>
                            <?php endif; ?>
                            <?php if($social_lnk) : ?>
                            <li class="c-circle-nav__item">
                                <a href="#" class="c-circle-nav__link">
                                    <i class="fa fa-linkedin"></i>
                                </a>
                            </li>
                            <?php endif; ?>
                            <?php if($social_ytube != '') : ?>
                            <li class="c-circle-nav__item">
                                <a href="#" class="c-circle-nav__link">
                                    <i class="fa fa-youtube"></i>
                                </a>
                            </li>
                            <?php endif; ?>
                        </ul>
                    </div>
                    <div>
                        <a class="social-toggle" href="#"><i class="fa fa-share-alt"></i></a>
                    </div>
                </div>
            <?php endif; ?>
            
            <?php /*
            <?php if(is_active_sidebar('header-widget')) : ?>
                <div class="header-social-icons-container">
                    <div class="rvl-header-social-icons">
                        <?php dynamic_sidebar('header-widget'); ?>
                    </div>
                    <div>
                        <a class="social-toggle" href="#" "email me"><i class="fa fa-share-alt"></i></a>
                    </div>
                </div>
            <?php endif; ?>
            */ ?>
    	</div> <!-- revolve-side-nav -->
        <?php if(!is_page_template('tpl-home.php' )) : ?>
        <div id="revolve-page-content">
        <?php endif; ?>