<?php
    add_action( 'add_meta_boxes', 'revolve_add_custom_box' );
    
    function revolve_add_custom_box() {
        /** Metabox for Page **/
            add_meta_box(
                'revolve-page-options',
                __('Page Options','revolve'),
                'revolve_page_options',
                'page',
                'normal',
                'default'
            );
    }
    
    function revolve_page_options() {
        global $post;
        wp_nonce_field( basename( __FILE__ ), 'revolve_page_options' );
        
        /** Home Slider Options **/
        $hm_poster_display = get_post_meta( $post->ID, 'hm_poster_display', true );
        if(empty($hm_poster_display)){$hm_poster_display = '';};
        
        $hm_poster_order = get_post_meta( $post->ID, 'hm_poster_order', true );
        if(empty($hm_poster_order)){$hm_poster_order = 0;};
        
        $hm_poster_image = get_post_meta( $post->ID, 'hm_poster_image', true );
        if(empty($hm_poster_image)){$hm_poster_image = '';};
        
        $hm_poster_caption_title = get_post_meta( $post->ID, 'hm_poster_caption_title', true );
        if(empty($hm_poster_caption_title)){$hm_poster_caption_title = '';};
        
        $hm_poster_caption_descr = get_post_meta( $post->ID, 'hm_poster_caption_descr', true );
        if(empty($hm_poster_caption_descr)){$hm_poster_caption_descr = '';};
        
        /** Custom Page ID **/
        $cus_page_id = get_post_meta( $post->ID, 'cus_page_id', true );
        if(empty($cus_page_id)){$cus_page_id = $post->post_name;};
        
        $post_id = 0;
        $home_style = '';
        $id_style = '';
        if(isset($_REQUEST['post'])){
            $post_id = $_REQUEST['post'];
        }
        
        ?>
            <div class="page-options home-slider-poster-options" >
                <h2 class="page-option-title"><?php _e('Home Slider Options', 'revolve'); ?></h2>
                <p>
                    Configure the Home slider option for the pages which you wish to display in the home page.
                </p>
                <table>
                    <tr>
                        <th><label for="hm_poster_display"><?php _e('Display as Slider : ', 'revolve'); ?></label></th>
                        <td>
                            <input id="hm_poster_display" type="checkbox" name="hm_poster_display" value="1" <?php checked(true, $hm_poster_display); ?> />
                            <em><?php _e('Check to display as homeslider', 'revolve'); ?></em>
                        </td>
                    </tr>
                    <tr><th colspan="2"><br /></th></tr>
                    <tr> 
                        <th><label for="hm_poster_image"><?php _e('Poster Image : ', 'revolve'); ?></label></th>
                        <td>
                            <input class="upload" type="text" name="hm_poster_image" id="hm_poster_image" placeholder="http://path/to/image.png" value="<?php echo esc_url_raw($hm_poster_image); ?>" />
                            <span class="poster_upload_btn"><?php _e('Upload', 'revolve'); ?></span>
                            <div class="img_preview">
                                <?php if($hm_poster_image != '') : ?>
                                    <img src="<?php echo esc_url_raw($hm_poster_image); ?>" />
                                    <a class="img-rem-btn">X</a>
                                <?php endif; ?>
                            </div>
                        </td>
                    </tr>
                    <tr>
                        <th><label for="hm_poster_caption_title"><?php _e('Poster Caption Title : ', 'revolve'); ?></label></th>
                        <td>
                            <input type="text" name="hm_poster_caption_title" id="hm_poster_caption_title" placeholder="Caption Title" value="<?php echo esc_attr($hm_poster_caption_title); ?>" />
                        </td>
                    </tr>
                    <tr>
                        <th><label for="hm_poster_caption_descr"><?php _e('Poster Caption Description : ', 'revolve'); ?></label></th>
                        <td>
                            <textarea name="hm_poster_caption_descr" id="hm_poster_caption_descr" placeholder="Caption Description" ><?php echo wp_kses_post($hm_poster_caption_descr); ?></textarea>
                        </td>
                    </tr>
                </table>
            </div>
            
            <div class="page-options child-page-id-options" >
                <h2><?php _e('Page ID', 'revolve'); ?></h2>
                <div>
                <p>
                    If you configure to display the subpages of the parent pages as the part of the parent page's section from Dashboard > Appearance > Menu. The slug of the sub-pages will be used to denote the section's id by default. You may change the default id below. 
                </p>
                <p>
                    This option is applicable for child pages only.
                </p>
                </div>
                <table>
                    <tr>
                        <th><label for="cus_page_id"><?php _e('Page ID : ', 'revolve'); ?></label></th>
                        <td>
                            <input type="text" name="cus_page_id" value="<?php echo $cus_page_id; ?>" /><br />
                            <em><?php _e('If left empty default slug of the page will be used', 'revolve'); ?></em>
                        </td>
                    </tr>

                </table>
            </div>
        <?php
    }
    
    add_action('save_post', 'revolve_home_slider_save_options');
    
    function revolve_home_slider_save_options($post_id) {
        global $post;
        
        if ( !isset( $_POST[ 'revolve_page_options' ] ) || !wp_verify_nonce( $_POST[ 'revolve_page_options' ], basename( __FILE__ ) ) )
            return;
        
        // Stop WP from clearing custom fields on autosave
        if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE)  
            return;
        
        if ('page' == $_POST['post_type']) {  
            if (!current_user_can( 'edit_post', $post_id ) ) {  
                return $post_id;
            }
        }
        
        /** Sanitize Inputs. **/
        if(isset($_POST['hm_poster_display'])){
            $hm_poster_display = 1;
        } else {
            $hm_poster_display = '';
        }

        $hm_poster_image = esc_url_raw( $_POST['hm_poster_image'] );
        $hm_poster_caption_title = sanitize_text_field( $_POST['hm_poster_caption_title'] );
        $hm_poster_caption_descr = wp_kses_post( $_POST['hm_poster_caption_descr'] );
        
        $cus_page_id = sanitize_text_field( $_POST['cus_page_id'] );
        
        /** Update Options **/
        update_post_meta( $post_id, 'hm_poster_display', $hm_poster_display );
        update_post_meta( $post_id, 'hm_poster_image', $hm_poster_image );
        update_post_meta( $post_id, 'hm_poster_caption_title', $hm_poster_caption_title );
        update_post_meta( $post_id, 'hm_poster_caption_descr', $hm_poster_caption_descr );
        
        update_post_meta( $post_id, 'cus_page_id', $cus_page_id );
    }
    
    function revolve_is_parent_page($pageid) {
        $pg = get_page($pageid);
        if($pg->post_parent == 0) {
            return true;
        } else{
            return false;            
        }
    }
?>